@@ -6,7 +6,7 @@
  *   copyright            : (C) 2001 The phpBB Group
  *   email                : support@phpbb.com
  *
- *   $Id: groupcp.php,v 1.58.2.19 2003/12/30 14:17:49 psotfx Exp $
+ *   $Id: groupcp.php,v 1.58.2.22 2004/11/18 17:49:34 acydburn Exp $
  *
  *
  ***************************************************************************/
@@ -425,7 +425,7 @@ else if ( $group_id )
 			$sql = "SELECT g.group_moderator, g.group_type, aa.auth_mod 
 				FROM " . GROUPS_TABLE . " g, " . AUTH_ACCESS_TABLE . " aa 
 				WHERE g.group_id = $group_id
-					AND aa.group_id = g.group_id(+)";
+					AND aa.group_id (+) = g.group_id";
 			break;
 
 		default:
@@ -472,7 +472,7 @@ else if ( $group_id )
 
 			if ( isset($HTTP_POST_VARS['add']) )
 			{
-				$username = ( isset($HTTP_POST_VARS['username']) ) ? htmlspecialchars($HTTP_POST_VARS['username']) : '';
+				$username = ( isset($HTTP_POST_VARS['username']) ) ? phpbb_clean_username($HTTP_POST_VARS['username']) : '';
 				
 				$sql = "SELECT user_id, user_email, user_lang, user_level  
 					FROM " . USERS_TABLE . " 
@@ -1149,6 +1149,8 @@ else
 	// Select all group that the user is a member of or where the user has
 	// a pending membership.
 	//
+	$in_group = array();
+	
 	if ( $userdata['session_logged_in'] ) 
 	{
 		$sql = "SELECT g.group_id, g.group_name, g.group_type, ug.user_pending 
@@ -1243,7 +1245,7 @@ else
 			$template->assign_block_vars('switch_groups_remaining', array() );
 		}
 
-		$s_hidden_fields = '';
+		$s_hidden_fields = '<input type="hidden" name="sid" value="' . $userdata['session_id'] . '" />';
 
 		$template->assign_vars(array(
 			'L_GROUP_MEMBERSHIP_DETAILS' => $lang['Group_member_details'],
