@@ -3,9 +3,9 @@
 /***************************************************************************
  *                            lang_admin.php [romn]
  *                              -------------------
- *     begin                : Sat Sep 7 2002
- *     last update          : May 29, 2003
- *     language version     : 3.0
+ *     begin                : Sep 7 2002
+ *     last update          : Dec 31, 2004
+ *     language version     : 6.0
  *     copyright            : Romanian phpBB online community
  *     website              : http://www.phpbb.ro
  *     copyright 1          : (C) Daniel Tnasie
@@ -87,7 +87,7 @@ $lang['Number_topics'] = 'Numrul subiectelor';
 $lang['Topics_per_day'] = 'Subiecte pe zi';
 $lang['Number_users'] = 'Numrul utilizatorilor';
 $lang['Users_per_day'] = 'Utilizatori pe zi';
-$lang['Board_started'] = 'Data pornirii forumului';
+$lang['Board_started'] = 'Data lansrii forumului';
 $lang['Avatar_dir_size'] = 'Dimensiunea directorului cu imagini asociate (Avatar)';
 $lang['Database_size'] = 'Dimensiunea bazei de date';
 $lang['Gzip_compression'] ='Compresia Gzip';
@@ -103,13 +103,13 @@ $lang['OFF'] = 'Inactiv';
 $lang['Database_Utilities'] = 'Instrumentele bazei de date';
 
 $lang['Restore'] = 'Restaurare';
-$lang['Backup'] = 'Salvare(Backup)';
-$lang['Restore_explain'] = 'Aceasta va efectua o resturare complet a tuturor tabelelor phpBB dintr-in fiier salvat. Dac serverul dumneavoastr suport, putei publica un fiier text compresat cu gzip i aceasta va fi decomprimat automat. <b>ATENIE:</b> Aceast procedur va rescrie orice informaie deja existent. Procesul de restaurare poate dura un timp ndelungat; v rugm nu prsii aceast pagin pn cnd restaurarea nu se termin.';
+$lang['Backup'] = 'Salvare (Backup)';
+$lang['Restore_explain'] = 'Aceasta va efectua o restaurare complet a tuturor tabelelor phpBB dintr-in fiier salvat. Dac serverul dumneavoastr suport, putei publica un fiier text compresat cu gzip i aceasta va fi decomprimat automat. <b>ATENIE:</b> Aceast procedur va rescrie orice informaie deja existent. Procesul de restaurare poate dura un timp ndelungat; v rugm nu prsii aceast pagin pn cnd restaurarea nu se termin.';
 $lang['Backup_explain'] = 'Aici putei face copii de rezerv ale tuturor datelor ce in de phpBB. Dac avei i tabele adiionale n aceeai baz de date cu phpBB-ul pe care dorii s le pstrai, v rugm s introducei numele lor separate prin virgul n csua <i>Tabele Suplimentare</i> de mai jos. Dac serverul dumneavoastr suport, putei comprima fiierul cu gzip pentru a reduce dimensiunea sa nainte de a efectua operaiunea de descrcare.';
 
-$lang['Backup_options'] = 'Opiunile de backup';
-$lang['Start_backup'] = 'Pornete operaiunea de backup';
-$lang['Full_backup'] = 'Backup total';
+$lang['Backup_options'] = 'Opiunile de salvare (backup)';
+$lang['Start_backup'] = 'Pornete operaiunea de salvare (backup)';
+$lang['Full_backup'] = 'Salvare (Backup) total';
 $lang['Structure_backup'] = 'Salveaz (copie de siguran) doar structura';
 $lang['Data_backup'] = 'Salveaz (copie de siguran) doar datele';
 $lang['Additional_tables'] = 'Tabele suplimentare';
@@ -119,9 +119,9 @@ $lang['Start_Restore'] = 'Pornete operaiunea de restaurare';
 
 $lang['Restore_success'] = 'Baza de date a fost restaurat cu succes.<br /><br />Forumul dumneavoastr ar trebui s revin la starea lui nainte ca salvarea s se fi realizat.';
 $lang['Backup_download'] = 'Operaiunea de descrcare va ncepe n curnd; v rugm s ateptai pn aceasta va ncepe';
-$lang['Backups_not_supported'] = 'Scuze, dar efectuarea backup-ului nu este n prezent realizabil pentru sistemul dumneavoastr de baze de date';
+$lang['Backups_not_supported'] = 'Scuzai, dar efectuarea salvrii (backup-ului) nu este n prezent realizabil pentru sistemul dumneavoastr de baze de date';
 
-$lang['Restore_Error_uploading'] = 'Eroare la publicarea fiierului de backup';
+$lang['Restore_Error_uploading'] = 'Eroare la publicarea fiierului de salvare (backup)';
 $lang['Restore_Error_filename'] = 'Problem cu numele fiierului; v rugm, ncercai cu un alt fiier';
 $lang['Restore_Error_decompress'] = 'Nu pot decomprima un fiier gzip; v rugm, publicai o versiune text ntreg (plain text)';
 $lang['Restore_Error_no_file'] = 'Nici un fiier nu a fost publicat/ncrcat';
@@ -179,13 +179,13 @@ $lang['Post'] = 'Scriere';
 $lang['Reply'] = 'Rspunde';
 $lang['Edit'] = 'Modific';
 $lang['Delete'] = 'terge';
-$lang['Sticky'] = 'Lipicios (Sticky)';
+$lang['Sticky'] = 'Important';
 $lang['Announce'] = 'Anun';
 $lang['Vote'] = 'Vot';
 $lang['Pollcreate'] = 'Creare sondaj';
 
 $lang['Permissions'] = 'Permisiuni';
-$lang['Simple_Permission'] = 'Premisiune simpl';
+$lang['Simple_Permission'] = 'Permisiune simpl';
 
 $lang['User_Level'] = 'Nivelul utilizatorului';
 $lang['Auth_User'] = 'Utilizator';
@@ -309,7 +309,7 @@ $lang['Avatar_gallery_path'] = 'Calea de pstrare a galeriilor cu imagini asociat
 $lang['Avatar_gallery_path_explain'] = 'Calea aflat n directorul dumneavoastr phpBB, de exemplu. imagini/avatar/galerie';
 
 $lang['COPPA_settings'] = 'Configurrile COPPA';
-$lang['COPPA_fax'] = 'Numrul de fax Fax Number';
+$lang['COPPA_fax'] = 'Numrul de fax';
 $lang['COPPA_mail'] = 'Adresa potal COPPA';
 $lang['COPPA_mail_explain'] = 'Aceasta este adresa potal unde prinii vor trimite formularele de nregistrare COPPA';
 
@@ -317,7 +317,7 @@ $lang['Email_settings'] = 'Configurrile de email';
 $lang['Admin_email'] = 'Adresa de email a administratorului';
 $lang['Email_sig'] = 'Semntura din email';
 $lang['Email_sig_explain'] = 'Acest text va fi ataat la toate mesajele pe care forumul le trimite';
-$lang['Use_SMTP'] = 'Folosii serverul SMTP Server pentru email';
+$lang['Use_SMTP'] = 'Folosii serverul SMTP pentru email';
 $lang['Use_SMTP_explain'] = 'Specificai da dac dorii sau avei nevoie s trimitei mesaje printr-un alt server n loc s folosii funcia local de mesagerie';
 $lang['SMTP_server'] = 'Adresa serverului SMTP';
 $lang['SMTP_username'] = 'Numele de utilizator SMTP';
@@ -326,9 +326,9 @@ $lang['SMTP_password'] = 'Parola SMTP';
 $lang['SMTP_password_explain'] = 'Introducei parola doar dac serverul dumneavoastr SMTP necesit aceast specificare';
 
 $lang['Disable_privmsg'] = 'Mesagerie privat';
-$lang['Inbox_limits'] = 'Numrul maxim al mesajelor n Dosarul cu mesaje (Inbox)';
-$lang['Sentbox_limits'] = 'Numrul maxim al mesajelor n Dosarul cu mesaje trimise (Sentbox)';
-$lang['Savebox_limits'] = 'Numrul maxim al mesajelor n Dosarul cu mesaje salvate (Savebox)';
+$lang['Inbox_limits'] = 'Numrul maxim al mesajelor n Cutia cu mesaje (Inbox)';
+$lang['Sentbox_limits'] = 'Numrul maxim al mesajelor n Cutia cu mesaje trimise (Sentbox)';
+$lang['Savebox_limits'] = 'Numrul maxim al mesajelor n Cutia cu mesaje salvate (Savebox)';
 
 $lang['Cookie_settings'] = 'Configurrile pentru cookie';
 $lang['Cookie_settings_explain'] = 'Aceste detalii definesc cum sunt cookie-urile trimise ctre browser-ele utilizatorilor. n cele mai multe cazuri valorile standard pentru setrile cookie-urilor ar trebui s fie suficiente dar dac trebuie s le schimbai avei mare grij, setrile incorecte pot mpiedica utilizatorii s se autentifice';
@@ -340,6 +340,11 @@ $lang['Cookie_secure_explain'] = 'Dac serverul dumneavoastr ruleaz via SSL, sele
 $lang['Session_length'] = 'Durata sesiunii [ secunde ]';
 
 
+// Visual Confirmation
+$lang['Visual_confirm'] = 'Activeaz Confirmarea Vizual';
+$lang['Visual_confirm_explain'] = 'Necesit introducerea unui cod vizual definit ca o imagine la nregistrare.';
+
+
 //
 // Forum Management
 //
@@ -671,7 +676,7 @@ $lang['img_pm_size'] = 'Dimensiunea statutului de mesaj privat [px]';
 //
 // Install Process
 //
-$lang['Welcome_install'] = 'Bine ai venit la procedura de instalare a formumului phpBB2';
+$lang['Welcome_install'] = 'Bine ai venit la procedura de instalare a forumului phpBB2';
 $lang['Initial_config'] = 'Configuraia de baz';
 $lang['DB_config'] = 'Configuraia bazei de date';
 $lang['Admin_config'] = 'Configuraia administratorului';
@@ -682,11 +687,11 @@ $lang['Installer_Error'] = 'O eroare a aprut n timpul instalrii';
 $lang['Previous_Install'] = 'O instalare anterioar a fost detectat';
 $lang['Install_db_error'] = 'O eroare a aprut n timpul actualizrii bazei de date';
 
-$lang['Re_install'] = 'Instalarea anterioar este nc activ. <br /><br />Dac dorii s reinstalai phpBB2-ul ar trebui s apsai pe butonul Da de mai jos. V rugm s avei grij ca s nu distrugei toate datele existente, nici o copie de siguran nu va fi fcut! Numele de utilizator i parola administratorului pe care le-ai folosit s v autentificai n forum vor fi recreate dup reinstalare, nici o alt setare nu va fi pstrat. <br /><br />Gndii-v atent nainte de a apsa butonul <i>Ponete instalarea</i>!';
+$lang['Re_install'] = 'Instalarea anterioar este nc activ. <br /><br />Dac dorii s reinstalai phpBB2-ul ar trebui s apsai pe butonul Da de mai jos. V rugm s avei grij ca s nu distrugei toate datele existente, nici o copie de siguran nu va fi fcut! Numele de utilizator i parola administratorului pe care le-ai folosit s v autentificai n forum vor fi recreate dup reinstalare, nici o alt setare nu va fi pstrat. <br /><br />Gndii-v atent nainte de a apsa butonul <i>Pornete instalarea</i>!';
 
 $lang['Inst_Step_0'] = 'V mulumim c ai ales phpBB2. Pentru a completa aceast instalare v rugm s completai detaliile de mai jos. Reinei c baza de date pe care o folosii trebuie s existe deja. Dac instalai ntr-o baz de date care folosete ODBC, de exemplu MS Access ar trebui mai nti s creai un DSN pentru aceasta nainte de a continua.';
 
-$lang['Start_Install'] = 'Ponete instalarea';
+$lang['Start_Install'] = 'Pornete instalarea';
 $lang['Finish_Install'] = 'Termin instalarea';
 
 $lang['Default_lang'] = 'Limba standard pentru forum';
@@ -705,7 +710,7 @@ $lang['Admin_Password_confirm'] = 'Parola administratorului [ Confirmai ]';
 $lang['Inst_Step_2'] = 'Numele de utilizator pentru administrator a fost creat. Acum instalarea de baz este complet. Va aprea un ecran care v va permite s administrai noua dumneavoastr instalare. Asigurai-v c ai verificat detaliile seciunii Configurare general i ai efectuat orice schimbare necesar. V mulumim c ai ales phpBB2.';
 
 $lang['Unwriteable_config'] = 'Fiierul dumneavoastr de configurare n acest moment este protejat la scriere. O copie a fiierului de configurare va fi descrcat cnd apsai butonul de mai jos. At trebui s ncrcai acest fiier n acelai director ca i phpBB2. Odat ce aceast operaiune este terminat ar trebui s v autentificai folosind numele de utilizator i parola administratorului pe care le-ai specificat n formularul anterior i s vizitai centrul de control al administratorului (o legtur va aprea la captul fiecrei pagini odat ce v-ai autentificat) ca s verificai configuraia general. V mulumim c ai ales phpBB2.';
-$lang['Download_config'] = 'Descarc configurarea';
+$lang['Download_config'] = 'Descarc fiierul de configurare';
 
 $lang['ftp_choose'] = 'Alegei metoda de descrcare';
 $lang['ftp_option'] = '<br />ntruct extensiile FTP sunt activate n aceast versiune a PHP-ului, avei posibilitatea de a ncerca s plasai prin ftp fiierul de configurare la locul lui.';
