@@ -7,7 +7,7 @@
  *     copyright            : (C) 2001 The phpBB Group
  *     email                : support@phpbb.com
  *
- *     $Id: lang_admin.php,v 1.35.2.9 2003/06/10 00:31:19 psotfx Exp $
+ *     $Id: lang_admin.php 1.36.0.1 2004/08/23 02:31:19 AlK
  *
  ****************************************************************************/
 /***************************************************************************
@@ -21,8 +21,8 @@
 
 /* CONTRIBUTORS
     Translation done by Ken Christensen (Dalixam) 2.0.4
-    Updated, overhaul to 2.0.6 by AlleyKat
-*/
+    Updates, overhauls to 2.0.10 by AlleyKat 
+	*/
 
 //
 // Format is same as lang_main
@@ -61,13 +61,13 @@ $lang['Restore_DB'] = "Genopret Database";
 $lang['Admin'] = "Administration";
 $lang['Not_admin'] = "Du er ikke autoriseret til at redigere dette forum";
 $lang['Welcome_phpBB'] = "Velkommen til phpBB";
-$lang['Admin_intro'] = "Tak fordi du valgte phpBB som dit forum. Denne skrm vil give dig et hurtigt overblik over alle de forskellige statistikker, der er tilgngelige om dit forum. Du kan komme tilbage til denne side ved at klikke p <u>Administrationsindeks</u> linket i venstre side. For at vende tilbage til dit forums indeksside skal du klikke p phpBB logoet, der ogs befinder sig i venstre side. De andre links i venstre side lader dig kontrollere og redigere hver eneste aspekt af dit forum, hver enkelt side indeholder instruktioner om, hvordan du bruger de forskellige vrktjer.";
+$lang['Admin_intro'] = "Tak fordi du valgte phpBB som dit forum. Denne skrm vil give dig et hurtigt overblik over alle de forskellige statistikker, der er tilgngelige om dit forum. Du kan komme tilbage til denne side ved at klikke p <u>Administrationsindeks</u> linket i venstre side. For at vende tilbage til dit forums indeksside kan du klikke p linket eller phpBB logoet, der ogs befinder sig i venstre side. De andre links i venstre side lader dig kontrollere og redigere hver eneste aspekt af dit forum; hver enkelt side indeholder instruktioner om, hvordan du bruger de forskellige vrktjer.";
 $lang['Main_index'] = "Forumindeks";
 $lang['Forum_stats'] = "Forum Statistikker";
 $lang['Admin_Index'] = "Administrationsindeks";
 $lang['Preview_forum'] = "Smugkig p forummet";
 
-$lang['Click_return_admin_index'] = "Klik %sHer%s for at vende tilbage til Administrationsindekset";
+$lang['Click_return_admin_index'] = "Klik %sher%s for at vende tilbage til Administrationsindekset";
 
 $lang['Statistic'] = "Statistikker";
 $lang['Value'] = "Vrdi";
@@ -111,7 +111,7 @@ $lang['Restore_success'] = "Databasen er blevet korrekt genoprettet.<br /><br />
 $lang['Backup_download'] = "Din download vil begynde om kort tid, vent venligst til den begynder";
 $lang['Backups_not_supported'] = "Desvrre, backups af databaser fra dit database-system understttes p nuvrende tidspunkt ikke";
 
-$lang['Restore_Error_uploading'] = "Der skete en fejl under uploading af backup-filen";
+$lang['Restore_Error_uploading'] = "Der skete en fejl under upload af backup-filen";
 $lang['Restore_Error_filename'] = "Der er et problem med filens navn, prv venligst med en alternativ fil";
 $lang['Restore_Error_decompress'] = "Gzip-filen kan ikke dekomprimeres, upload venligst en ren tekstversion";
 $lang['Restore_Error_no_file'] = "Ingen fil blev uploaded";
@@ -130,9 +130,9 @@ $lang['Look_up_User'] = "Sl Brugeren op";
 $lang['Look_up_Group'] = "Sl Gruppen op"; 
 $lang['Look_up_Forum'] = "Vis forum"; 
 
-$lang['Group_auth_explain'] = "Her kan du ndre rettighederne og redaktrstatussen, tilskrevet til hver enkelt brugergruppe. Glem ikke nr du ndrer grupperettigheder, at individuelle brugerrettigheder mske stadig tillader, at brugeren har adgang til forummerne, etc. Du bliver advaret, hvis dette er tilfldet.";
-$lang['User_auth_explain'] = "Her kan du ndre rettighederne og redaktrstatussen, tilskrevet til hver enkelt bruger. Glem ikke nr du ndrer brugerrettigheder, at grupperettigheder mske stadig tillader, at brugeren har adgang til forummerne, etc. Du bliver advaret, hvis dette er tilfldet.";
-$lang['Forum_auth_explain'] = "Her kan du ndre autoriseringsniveauer for de enkelte forummer. Du har bde en simpel og avanceret metode til rdighed. Den avancerede metode tillader strre kontrol af hvert enkelt forum. Husk, at nr du ndrer forummernes autoriseringsniveauerne, pvirker det hvilke brugere, der kan udfre de forskellige ting i dem.";
+$lang['Group_auth_explain'] = "Her kan du ndre rettighederne og redaktrstatus for hver enkelt brugergruppe. Glem ikke nr du ndrer grupperettigheder, at individuelle brugerrettigheder mske stadig tillader at brugeren har adgang til forummerne, etc. Du bliver advaret, hvis dette er tilfldet.";
+$lang['User_auth_explain'] = "Her kan du ndre rettighederne og redaktrstatus for hver enkelt bruger. Glem ikke nr du ndrer brugerrettigheder, at grupperettigheder mske stadig tillader at brugeren har adgang til forummerne, etc. Du bliver advaret, hvis dette er tilfldet.";
+$lang['Forum_auth_explain'] = "Her kan du ndre autoriseringsniveauer for de enkelte fora. Du har bde en simpel og avanceret metode til rdighed. Den avancerede metode tillader strre kontrol af hvert enkelt forum. Husk, at nr du ndrer forummernes autoriseringsniveauerne, pvirker det hvilke brugere der kan udfre de forskellige ting i dem.";
 
 $lang['Simple_mode'] = "Simpel Metode";
 $lang['Advanced_mode'] = "Avanceret Metode";
@@ -143,12 +143,12 @@ $lang['Disallowed_Access'] = "Ngtet Adgang";
 $lang['Is_Moderator'] = "Er Redaktr";
 $lang['Not_Moderator'] = "Er ikke Redaktr";
 
-$lang['Conflict_warning'] = "Advarsel om Autoriseringskonflikt";
-$lang['Conflict_access_userauth'] = "Denne bruger har stadig adgangsrettigheder til dette forum via et gruppemedlemsskab. Du skal nok ndre gruppens rettigheder eller fjerne denne bruger fra gruppen, for at forhindre, at de har adgangsrettigheder. Gruppens rettigheder (og forummerne involveret) er nvnt nedenunder.";
-$lang['Conflict_mod_userauth'] = "Denne bruger har stadig redaktrrettigheder til dette forum via et gruppemedlemsskab. Du skal nok ndre gruppens rettigheder eller fjerne denne bruger fra gruppen, for at forhindre, at de har redaktrrettigheder. Gruppens rettigheder (og forummerne involveret) er nvnt nedenunder.";
+$lang['Conflict_warning'] = "Advarsel om Autorisationskonflikt";
+$lang['Conflict_access_userauth'] = "Denne bruger har stadig adgangsrettigheder til dette forum via et gruppemedlemsskab. Du skal nok ndre gruppens rettigheder eller fjerne denne bruger fra gruppen, for at forhindre at vedkommende har adgangsrettigheder. Gruppens rettigheder (og forummerne involveret) er nvnt herunder.";
+$lang['Conflict_mod_userauth'] = "Denne bruger har stadig redaktrrettigheder til dette forum via et gruppemedlemsskab. Du skal nok ndre gruppens rettigheder eller fjerne denne bruger fra gruppen, for at forhindre at vedkommende har redaktrrettigheder. Gruppens rettigheder (og forummerne involveret) er nvnt herunder.";
 
-$lang['Conflict_access_groupauth'] = "Den flgende bruger (eller brugere) har stadig adgangsrettigheder til dette forum via deres brugerrettigheder. Du skal nok brugerrettighederne for at forhindre dem i, at have adgangsrettigheder. Brugernes rettigheder (og forummerne involveret) er nvnt nedenunder.";
-$lang['Conflict_mod_groupauth'] = "Den flgende bruger (eller brugere) har stadig redaktrrettigheder til dette forum via deres brugerrettigheder. Du skal nok brugerrettighederne for at forhindre dem i, at have redaktrrettigheder. Brugernes rettigheder (og forummerne involveret) er nvnt nedenunder.";
+$lang['Conflict_access_groupauth'] = "Den flgende bruger (eller brugere) har stadig adgangsrettigheder til dette forum via deres brugerrettigheder. Du skal nok brugerrettighederne for at forhindre dem i, at have adgangsrettigheder. Brugernes rettigheder (og forummerne involveret) er nvnt herunder.";
+$lang['Conflict_mod_groupauth'] = "Den flgende bruger (eller brugere) har stadig redaktrrettigheder til dette forum via deres brugerrettigheder. Du skal nok brugerrettighederne for at forhindre dem i, at have redaktrrettigheder. Brugernes rettigheder (og forummerne involveret) er nvnt herunder.";
 
 $lang['Public'] = "Offentlig";
 $lang['Private'] = "Privat";
@@ -159,7 +159,7 @@ $lang['Hidden'] = "Skjult";
 // These are displayed in the drop down boxes for advanced
 // mode forum auth, try and keep them short!
 $lang['Forum_ALL'] = "ALLE";
-$lang['Forum_REG'] = "REGISTRERET";
+$lang['Forum_REG'] = "REG";
 $lang['Forum_PRIVATE'] = "PRIVAT";
 $lang['Forum_MOD'] = "REDAKTR";
 $lang['Forum_ADMIN'] = "ADMIN";
@@ -189,16 +189,16 @@ $lang['User_auth_updated'] = "Brugerrettigheder opdateret";
 $lang['Group_auth_updated'] = "Grupperettigheder opdateret";
 
 $lang['Auth_updated'] = "Rettigheder er blevet opdateret";
-$lang['Click_return_userauth'] = "Klik %sHer%s for at vende tilbage til Brugerrettigheder";
-$lang['Click_return_groupauth'] = "Klik %sHer%s for at vende tilbage til Grupperettigheder";
-$lang['Click_return_forumauth'] = "Klik %sHer%s for at vende tilbage til Forumrettigheder";
+$lang['Click_return_userauth'] = "Klik %sher%s for at vende tilbage til Brugerrettigheder";
+$lang['Click_return_groupauth'] = "Klik %sher%s for at vende tilbage til Grupperettigheder";
+$lang['Click_return_forumauth'] = "Klik %sher%s for at vende tilbage til Forumrettigheder";
 
 
 //
 // Banning
 //
 $lang['Ban_control'] = "Kontrollering af bandlysninger";
-$lang['Ban_explain'] = "Her kan du kontrollere bandlysning af brugere. Du kan opn dette, ved enten at bandlyse en specifik bruger, en eller flere IP adresser eller domainnavne. Disse metoder forhindrer en bruger i overhovedet at f adgang til dit forums indexside. For at forhindre, at en bruger registrerer sig under en andet brugernavn, kan du ogs bandlyse en email adresse. Husk, bandlysning af en email adresse vil ikke forhindre den bruger i at logge p eller komme med nye indlg p dit forum, du skal bruge en af de frstnvnte metoder for, at forhindre dette.";
+$lang['Ban_explain'] = "Her kan du kontrollere bandlysning af brugere. Du kan opn dette, ved enten at bandlyse en specifik bruger, en eller flere IP adresser eller domainnavne. Disse metoder forhindrer en bruger i overhovedet at f adgang til dit forums indeksside. For at forhindre, at en bruger registrerer sig under en andet brugernavn, kan du ogs bandlyse en email adresse. Husk, bandlysning af en email adresse vil ikke forhindre den bruger i at logge p eller komme med nye indlg p dit forum, du skal bruge en af de frstnvnte metoder, for at forhindre dette.";
 $lang['Ban_explain_warn'] = "Bemrk venligst, at hvis du indtaster en rkke IP adresser vil dette resultere i, at alle adresserne mellem start og slut bliver tilfjet listen over bandlyste IP adresser. Forsg p, at minimere antallet af adresser tilfjet til databasen, vil blive foretaget ved automatisk at introducere jokere, nr det er passende. Hvis du virkelig vil indtaste en rkke adresser, s prv at minimere rkken eller endnu bedre, indtast specifikke adresser.";
 
 $lang['Select_username'] = "Vlg et Brugernavn";
@@ -229,35 +229,35 @@ $lang['No_banned_ip'] = "Ingen bandlyste IP adresser";
 $lang['No_banned_email'] = "Ingen bandlyste email adresser";
 
 $lang['Ban_update_sucessful'] = "Listen med oplysningerne om bandlysninger er korrekt opdateret.";
-$lang['Click_return_banadmin'] = "Klik %sHer%s for at vende tilbage til Kontrollering af bandlysninger";
+$lang['Click_return_banadmin'] = "Klik %sher%s for at vende tilbage til Kontrol af bandlysninger";
 
 
 //
 // Configuration
 //
 $lang['General_Config'] = "Generel Konfiguration";
-$lang['Config_explain'] = "Nedenstende skema giver dig mulighed for, at tilpasse alle de generelle forumindstillinger. For Bruger og Forumindstilninger, brug de relaterende links i venstre side.";
+$lang['Config_explain'] = "Nedenstende skema giver dig mulighed for at tilpasse alle de generelle forumindstillinger. For Bruger og Forumindstilninger, brug de relaterende links i venstre side.";
 
 $lang['Click_return_config'] = "Klik %sHer%s for at vende tilbage til Generel Konfiguration";
 
 $lang['General_settings'] = "Generelle forumindstillinger";
 $lang['Server_name'] = "Domnenavn";
-$lang['Server_name_explain'] = "Domnet dette forum ligger p";
-$lang['Script_path'] = "Script Adresse";
-$lang['Script_path_explain'] = "Adressen til phpBB2 p domnenavnet";
+$lang['Server_name_explain'] = "Domnet dette forum ligger p, feks. minside.dk";
+$lang['Script_path'] = "Sti til forummet";
+$lang['Script_path_explain'] = "Stien til phpBB2 p domnenavnet, feks. /forum/ eller /phpBB2/";
 $lang['Server_port'] = "Server Port";
 $lang['Server_port_explain'] = "Porten hvorp din server krer. Det er normalt 80, ndre kun hvis ndvendigt";
 $lang['Site_name'] = "Sidens navn";
 $lang['Site_desc'] = "Beskrivelse af siden";
 $lang['Board_disable'] = "Sl forummet fra";
-$lang['Board_disable_explain'] = "Dette vil gre forummet utilgngeligt for brugere. Du m ikke logge ud, nr du har slet forummet fra. Du vil ikke kunne logge p igen!";
+$lang['Board_disable_explain'] = "Dette vil gre forummet utilgngeligt for brugere. Du m ikke logge ud, nr du har slet forummet fra. Du vil ikke kunne logge p igen! Du kan dog ndre denne status direkte i databasen og derigennem genaktivere forummet.";
 $lang['Acct_activation'] = "Aktivering af Konto";
 $lang['Acc_None'] = "Ingen"; // These three entries are the type of activation
 $lang['Acc_User'] = "Bruger";
 $lang['Acc_Admin'] = "Administrator";
 
 $lang['Abilities_settings'] = "Generelle Bruger- og Forumindstillinger";
-$lang['Max_poll_options'] = "Maximum antal afstemningsmuligheder";
+$lang['Max_poll_options'] = "Maksimum antal afstemningsmuligheder";
 $lang['Flood_Interval'] = "Sekunder mellem indlg";
 $lang['Flood_Interval_explain'] = "Antal sekunder en bruger skal vente, fr et nyt indlg kan skrives."; 
 $lang['Board_email_form'] = "Bruger-email via forum";
@@ -281,7 +281,7 @@ $lang['Allow_smilies'] = "Tillad Smilies";
 $lang['Smilies_path'] = "Adressen hvor dine Smilies opbevares";
 $lang['Smilies_path_explain'] = "Adressen under din phpBB folder, f.eks. images/smilies";
 $lang['Allow_sig'] = "Tillad Underskrifter";
-$lang['Max_sig_length'] = "Maksimal lndge p underskrifter";
+$lang['Max_sig_length'] = "Maksimal lngde p underskrifter";
 $lang['Max_sig_length_explain'] = "Maksimale antal tegn i brugernes underskrifter";
 $lang['Allow_name_change'] = "Tillad, at brugerne kan ndre brugernavn";
 
@@ -322,12 +322,12 @@ $lang['Sentbox_limits'] = "Maksimale antal indlg i Sendt-bakken";
 $lang['Savebox_limits'] = "Maksimale antal indlg i Gemt-bakken";
 
 $lang['Cookie_settings'] = "Cookie indstillinger"; 
-$lang['Cookie_settings_explain'] = "Disse kontrollere, hvordan en cookie defineres af en browser. I de fleste tilflde skulle standard indstillingerne vre gode nok. Hvis du har brug for at ndre dem, s pas p, forkerte indstillinger kan resultere i, at brugere ikke kan logge p.";
+$lang['Cookie_settings_explain'] = "Disse kontrollerer hvordan en cookie defineres af en browser. I de fleste tilflde skulle standard indstillingerne vre gode nok. Hvis du har brug for at ndre dem, s pas p, forkerte indstillinger kan resultere i, at brugere ikke kan logge p.";
 $lang['Cookie_domain'] = "Cookie domne";
 $lang['Cookie_name'] = "Cookie navn";
 $lang['Cookie_path'] = "Cookie adresse";
 $lang['Cookie_secure'] = "Cookie sikkerhed [ https ]";
-$lang['Cookie_secure_explain'] = "Sl dette til hvis din server krer via SSL ellers lad det vre slet fra";
+$lang['Cookie_secure_explain'] = "Sl dette til hvis din server krer via SSL, ellers lad det vre slet fra";
 $lang['Session_length'] = "Lngden p en Session [ sekunder ]";
 
 // Visual Confirmation
@@ -338,7 +338,7 @@ $lang['Visual_confirm_explain'] = 'Krver at brugeren indtaster en kode defineret
 // Forum Management
 //
 $lang['Forum_admin'] = "Forum Administration";
-$lang['Forum_admin_explain'] = "Fra denne kan du tilfje, slette, ndre, omorganisere og gensynkronisere kategorier og forummer.";
+$lang['Forum_admin_explain'] = "Fra denne side kan du tilfje, slette, ndre, omorganisere og gensynkronisere kategorier og forummer.";
 $lang['Edit_forum'] = "ndre forum";
 $lang['Create_forum'] = "Opret nyt forum";
 $lang['Create_category'] = "Opret ny kategori";
@@ -351,7 +351,7 @@ $lang['Delete'] = "Slet";
 $lang['Move_up'] = "Ryk op";
 $lang['Move_down'] = "Ryk ned";
 $lang['Resync'] = "Re-synkronisr";
-$lang['No_mode'] = "Ingen memode blev valgt";
+$lang['No_mode'] = "Ingen metode blev valgt";
 $lang['Forum_edit_delete_explain'] = "Skemaet nedenfor gr at du kan tilpasse alle de generelle forumindstillinger. For Bruger og det enkelte Forums indstillinger skal du bruge linkene til venstre.";
 
 $lang['Move_contents'] = "Flyt alt indhold";
@@ -382,7 +382,7 @@ $lang['Forums_updated'] = "Forum- og Kategoriinformation korrekt opdateret";
 
 $lang['Must_delete_forums'] = "Du skal slette alle fora, fr du kan slette denne kategori";
 
-$lang['Click_return_forumadmin'] = "Klik %sHer%s for at vende tilbage til Forum Administration";
+$lang['Click_return_forumadmin'] = "Klik %sher%s for at vende tilbage til Forum Administration";
 
 
 //
@@ -391,9 +391,9 @@ $lang['Click_return_forumadmin'] = "Klik %sHer%s for at vende tilbage til Forum
 $lang['smiley_title'] = "Smiles Vrktjer";
 $lang['smile_desc'] = "Fra denne side, kan du tilfje, slette og ndre de smileys dine brugere kan bruge i deres indlg og private beskeder.";
 
-$lang['smiley_config'] = "Smiley Indstillinger";
-$lang['smiley_code'] = "Smiley Kode";
-$lang['smiley_url'] = "Smiley Billede Fil";
+$lang['smiley_config'] = "Smileyindstillinger";
+$lang['smiley_code'] = "Smileykode";
+$lang['smiley_url'] = "Smiley Billedfil";
 $lang['smiley_emot'] = "Smiley Udtryk";
 $lang['smile_add'] = "Tilfj en ny Smiley";
 $lang['Smile'] = "Smil";
@@ -407,7 +407,7 @@ $lang['smiley_import'] = "Smiley-pakke-import";
 $lang['choose_smile_pak'] = "Vlg en Smileypakke-fil (.pak)";
 $lang['import'] = "Importr Smileys";
 $lang['smile_conflicts'] = "Hvad skal gres i tilflde af konflikter";
-$lang['del_existing_smileys'] = "Slet eksisterende smileys inden importering";
+$lang['del_existing_smileys'] = "Slet eksisterende smileys inden import";
 $lang['import_smile_pack'] = "Importr Smiley-pakke";
 $lang['export_smile_pack'] = "Opret Smiley-pakke";
 $lang['export_smiles'] = "For at oprette en smiley-pakke med dine nuvrende installerede smileys, klik %sHer%s for at downloade smiles.pak filen. Giv den et passende navn og srg for at den beholder .pak efternavnet. Lav s en zipfil der indeholder alle smiley-billederne plus denne .pak konfigurationsfil.";
@@ -416,7 +416,7 @@ $lang['smiley_add_success'] = "Smileyen blev korrekt tilfjet";
 $lang['smiley_edit_success'] = "Smileyen blev korrekt opdateret";
 $lang['smiley_import_success'] = "Smiley-pakken blev korrekt importeret!";
 $lang['smiley_del_success'] = "Smileyen blev korrekt fjernet";
-$lang['Click_return_smileadmin'] = "Klik %sHer%s for at vende tilbage til Smiley Administration";
+$lang['Click_return_smileadmin'] = "Klik %sher%s for at vende tilbage til Smiley Administration";
 
 
 //
@@ -429,7 +429,7 @@ $lang['Look_up_user'] = "Sl bruger op";
 
 $lang['Admin_user_fail'] = "Brugerens profil kunne ikke opdaters.";
 $lang['Admin_user_updated'] = "Brugerens profil blev korrekt opdateret.";
-$lang['Click_return_useradmin'] = "Klik %sHer%s for at vende tilbage til Bruger Administration";
+$lang['Click_return_useradmin'] = "Klik %sher%s for at vende tilbage til Bruger Administration";
 
 $lang['User_delete'] = "Slet denne bruger";
 $lang['User_delete_explain'] = "Klik her for at slette denne bruger. Det er permenent.";
@@ -441,7 +441,7 @@ $lang['User_allowavatar'] = "Kan vise en avatar";
 
 $lang['Admin_avatar_explain'] = "Her kan du se og slette brugerens nuvrende avatar.";
 
-$lang['User_special'] = "Specialle kun-administrator felter";
+$lang['User_special'] = "Specielle kun-administrator felter";
 $lang['User_special_explain'] = "Disse felter kan ikke ndres af brugerne. Her kan du bestemme deres status og ndre indstillinger, de ikke har adgang til.";
 
 
@@ -449,7 +449,7 @@ $lang['User_special_explain'] = "Disse felter kan ikke ndres af brugerne. Her ka
 // Group Management
 //
 $lang['Group_administration'] = "Gruppe Administration";
-$lang['Group_admin_explain'] = "Fra dette panel kan du administere alle dine brugergrupper, du kan; slette, oprette og ndre eksisterende grupper. Du kan vlge redaktrer, sl grupper til og fra og bestemme gruppens navn og beskrivelse";
+$lang['Group_admin_explain'] = "Fra dette panel kan du administere alle dine brugergrupper, du kan slette, oprette og ndre eksisterende grupper. Du kan vlge redaktrer, sl grupper til og fra og bestemme gruppens navn og beskrivelse";
 $lang['Error_updating_groups'] = "Der opstod en fejl under opdateringen af grupperne";
 $lang['Updated_group'] = "Gruppen blev korrekt opdateret";
 $lang['Added_new_group'] = "Den nye gruppe blev korrekt oprettet";
@@ -473,7 +473,7 @@ $lang['No_group_mode'] = "Du skal vlge en status for denne gruppe, ben eller luk
 $lang['No_group_action'] = 'Ingen metode valgt';
 $lang['delete_group_moderator'] = "Slet den gamle grupperedaktr?";
 $lang['delete_moderator_explain'] = "Hvis du ndrer grupperedaktren, st kryds i dette felt for at slette den gamle redaktr fra gruppen. Hvis du ikke stter kryds, bliver brugeren et normalt medlem af gruppen.";
-$lang['Click_return_groupsadmin'] = "Klik %sHer%s for at vende tilbage til Gruppe Administration.";
+$lang['Click_return_groupsadmin'] = "Klik %sher%s for at vende tilbage til Gruppe Administration.";
 $lang['Select_group'] = "Vlg en gruppe";
 $lang['Look_up_group'] = "Vis Gruppe";
 
@@ -509,27 +509,27 @@ $lang['Word_updated'] = "Den valgte ordcensur blev korrekt opdateret";
 $lang['Word_added'] = "Ordcensuren blev korrekt tilfjet";
 $lang['Word_removed'] = "Den valgte ordcensur blev korrekt fjernet";
 
-$lang['Click_return_wordadmin'] = "Klik %sHer%s for at vende tilbage til Censurering af ord";
+$lang['Click_return_wordadmin'] = "Klik %sher%s for at vende tilbage til Censurering af ord";
 
 
 //
 // Mass Email
 //
-$lang['Mass_email_explain'] = "Her kan du sende email til alle dine brugere eller alle brugere i en specifik gruppe. For at gre dette, bliver en email sent til alle de administrative email adresser angivet og en kopi sendes til alle modtagere. Hvis du emailer en stor gruppe mennesker, skal du vre tlmodig efter, at du har sendt emailen og stop ikke siden, nr den er halvvejs. Det er normalt, at det tager lang tid, du fr at vide, nr emailen er frdigsendt.";
+$lang['Mass_email_explain'] = "Her kan du sende email til alle dine brugere eller alle brugere i en specifik gruppe. For at gre dette bliver en email sendt til alle de administrative email adresser, og en kopi sendes til alle modtagere. Hvis du emailer en stor gruppe mennesker, skal du vre tlmodig, da det godt kan tage lang tid at sende mailen til en stor gruppe. Stop ikke siden nr den er halvvejs, da processen vil g i st, og ikke alle i den angivne gruppe vil modtage emailen. Du fr at vide, nr mailen er frdigsendt.";
 $lang['Compose'] = "Skriv"; 
 
 $lang['Recipients'] = "Modtagere"; 
 $lang['All_users'] = "Alle Brugere";
 
 $lang['Email_successfull'] = "Din besked er afsendt";
-$lang['Click_return_massemail'] = "Klik %sHer%s for at vende tilbage til Gruppe email";
+$lang['Click_return_massemail'] = "Klik %sher%s for at vende tilbage til Gruppe email";
 
 
 //
 // Ranks admin
 //
 $lang['Ranks_title'] = "Rang-administration";
-$lang['Ranks_explain'] = "Ved at bruge denne side kan du tilfje, ndre, se og slette rang-niveauer. Du kan ogs oprettte specifikke niveauer, som kan gives til en bruger gennem brugervrktjerne.";
+$lang['Ranks_explain'] = "Ved at bruge denne side kan du tilfje, ndre, se og slette rang-niveauer. Du kan ogs oprette specifikke niveauer, som kan gives til en bruger gennem brugervrktjerne.";
 
 $lang['Add_new_rank'] = "Tilfj ny rang";
 
@@ -548,14 +548,14 @@ $lang['Rank_added'] = "Rangen blev korrekt tilfjet";
 $lang['Rank_removed'] = "Rangen blev korrekt slettet";
 $lang['No_update_ranks'] = 'Rangen blev korrekt slettet. Brugerkonti med denne rang blev dog ikke opdateret.  Du er ndt til manuelt at nulstille rangen for disse konti';
 
-$lang['Click_return_rankadmin'] = "Klik %sHer%s for at vende tilbage til Niveau Administration";
+$lang['Click_return_rankadmin'] = "Klik %sher%s for at vende tilbage til Niveau Administration";
 
 
 //
 // Disallow Username Admin
 //
 $lang['Disallow_control'] = "Forbyd Brugernavn Vrktjer";
-$lang['Disallow_explain'] = "Her kan du kontrollere, hvilke brugernavne der er tilladt. Forbudte brugernavne m indeholde en joker, betegnet som et *. Bemrk venligst, at du ikke kan forbyde et brugernavn, der allerede er registreret, du skal frst slette det navn og s forbyde det.";
+$lang['Disallow_explain'] = "Her kan du kontrollere, hvilke brugernavne der er tilladt. Forbudte brugernavne m indeholde en joker, betegnet som et *. Bemrk venligst, at du ikke kan forbyde et brugernavn, der allerede er registreret, du skal frst slette navnet og derefter forbyde det.";
 
 $lang['Delete_disallow'] = "Slet";
 $lang['Delete_disallow_title'] = "Fjern et forbudt brugernavn";
@@ -571,7 +571,7 @@ $lang['Disallowed_deleted'] = "Det forbudte brugernavn blev succesfuldt fjernet"
 $lang['Disallow_successful'] = "Det forbudte brugernavn blev korrekt tilfjet";
 $lang['Disallowed_already'] = "Navnet du indtastede kunne ikke forbydes. Enten eksisterer det allerede i listen, eksisterer i ordcensureringslisten, eller en bruger har det brugernavn";
 
-$lang['Click_return_disallowadmin'] = "Klik %sHer%s for at vende tilbage til Forbyd Brugernavn Vrktjer";
+$lang['Click_return_disallowadmin'] = "Klik %sher%s for at vende tilbage til Forbyd Brugernavn Vrktjer";
 
 
 //
@@ -611,7 +611,7 @@ $lang['No_template_dir'] = "Formskema biblioteket kunne ikke bnes. Det er muligv
 $lang['Cannot_remove_style'] = "Du kan ikke fjerne layoutet eftersom det p nuvrende tidspunkt er det layout, der er standard for forummet. ndre standardlayoutet og prv igen.";
 $lang['Style_exists'] = "Det valgte layout navn eksisterer allerede, g venligst tilbage og vlg et andet.";
 
-$lang['Click_return_styleadmin'] = "Klik %sHer%s for at vende tilbage til Layout Administration";
+$lang['Click_return_styleadmin'] = "Klik %sher%s for at vende tilbage til Layout Administration";
 
 $lang['Theme_settings'] = "Design indstillinger";
 $lang['Theme_element'] = "Design Element";
@@ -714,17 +714,17 @@ $lang['Transfer_config'] = "Start Upload";
 $lang['NoFTP_config'] = "Forsget p automatisk at uploade config filen slog fejl. Download venligst filen og upload den manuelt.";
 
 $lang['Install'] = "Installr";
-$lang['Upgrade'] = "Upgradr";
+$lang['Upgrade'] = "Opgradr";
 
 
 $lang['Install_Method'] = "Vlg installationsmetode";
 
 $lang['Install_No_Ext'] = "Php Konfigurationen p din server understtter ikke den type af database, som du har valgt"; 
 
-$lang['Install_No_PCRE'] = "PhpBB2 Krver Perl-Compatible Regular Expressions Modulet til php, hvilket din php konfiguration ikke lader til at understtte!"; 
+$lang['Install_No_PCRE'] = "PhpBB2 krver Perl-Compatible Regular Expressions-modulet til PHP, hvilket din php konfiguration ikke lader til at understtte!"; 
 
 //
 // That's all Folks!
 // -------------------------------------------------
 
-?>
\ No newline at end of file
+?>
