@@ -4,8 +4,8 @@
  *                            lang_admin.php [Swedish]
  *                              -------------------
  *     begin                : Sat Dec 16 2000
- *     copyright            : (C) 2001 The phpBB Group and (C) 2003 Jonathan Gulbrandsen
- *     email                : support@phpbb.com (translator:virtuality@carlssonplanet.com)
+ *     copyright            : (C) 2001 The phpBB Group
+ *     email                : support@phpbb.com
  *
  *     $Id: lang_admin.php,v 1.1.2.1 2002/05/19 17:32:51 psotfx Exp $
  *
@@ -46,16 +46,12 @@
 //  *************************************
 //
 
-/* CONTRIBUTORS
-	XXXX-XX-XX	
-                Orginal translation to Swedish by Marcus Svensson, Janke Rnnblom, Bruce and Jakob Persson
-		
-        2003-07-11 Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)
-                Updated the language file to phpBB2.0.5
-
-        2003-08-13 Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)
-                Updated to 2.0.6, no changes. Lots of "swinglish", grammars and mispellings fixed
-*/
+// CONTRIBUTORS:
+//	 Add your details here if wanted, e.g. Name, username, email address, website
+// XXXX-XX-XX  Orginal translation to Swedish by Marcus Svensson, Janke Rnnblom, Bruce and Jakob Persson
+// 2003-07-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.5
+// 2003-08-12  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.6
+// 2005-01-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.11
 
 //
 // Format is same as lang_main
@@ -65,17 +61,17 @@
 // Modules, this replaces the keys used
 // in the modules[][] arrays in each module file
 //
-$lang['General'] = "Generell administration";
-$lang['Users'] = "Anvndaradministration";
-$lang['Groups'] = "Gruppadministration";
-$lang['Forums'] = "Forumadministration";
-$lang['Styles'] = "Stiladministration";
+$lang['General'] = "Generell admin";
+$lang['Users'] = "Anvndaradmin";
+$lang['Groups'] = "Gruppadmin";
+$lang['Forums'] = "Forumadmin";
+$lang['Styles'] = "Stiladmin";
 
 $lang['Configuration'] = "Konfiguration";
 $lang['Permissions'] = "Rttigheter";
 $lang['Manage'] = "Hantering";
 $lang['Disallow'] = "Frbjuda namn";
-$lang['Prune'] = "Rensning";
+$lang['Prune'] = "Reducering";
 $lang['Mass_Email'] = "Mass email";
 $lang['Ranks'] = "Ranker";
 $lang['Smilies'] = "Smilies";
@@ -94,13 +90,13 @@ $lang['Restore_DB'] = "terstll databas";
 $lang['Admin'] = "Administration";
 $lang['Not_admin'] = "Du har inte rttighet att administrera detta forum";
 $lang['Welcome_phpBB'] = "Vlkommen till phpBB";
-$lang['Admin_intro'] = "Tack fr att du har valt phpBB som din forumlsning. Den hr sidan ger dig en snabb verblick ver all mjlig statistik om ditt forum. Du kan komma tillbaka till den hr sidan genom att klicka p <u>Admin start</u> lnken p den vnstra sidan. Fr att komma tillbaka till indexet till forumet tryck p phpBB logon, som finns i den vnstra panelen. De vriga lnkarna p vnster hand lter dig kontrollera alla aspekter p hur ditt forum presenteras, varje sidan har intruktioner p hur du anvnder verktygen.";
-$lang['Main_index'] = "Forumstart";
+$lang['Admin_intro'] = "Tack fr att du har valt phpBB som din forumlsning. Den hr sidan ger dig en snabb verblick ver all mjlig statistik om ditt forum. Du kan komma tillbaka till den hr sidan genom att klicka p <u>Admin index</u> lnken p den vnstra sidan. Fr att komma tillbaka till indexet till forumet tryck p phpBB logon, som finns i den vnstra panelen. De vriga lnkarna p vnster hand lter dig kontrollera alla aspekter p hur ditt forum presenteras, varje sidan har intruktioner p hur du anvnder verktygen.";
+$lang['Main_index'] = "Forumindex";
 $lang['Forum_stats'] = "Forumstatistik";
-$lang['Admin_Index'] = "Admin start";
+$lang['Admin_Index'] = "Admin index";
 $lang['Preview_forum'] = "Frhandsgranska forum";
 
-$lang['Click_return_admin_index'] = "Klicka %sHr%s fr att tervnda till Admin start";
+$lang['Click_return_admin_index'] = "Klicka %sHr%s fr att tervnda till Admin index";
 
 $lang['Statistic'] = "Statistik";
 $lang['Value'] = "Vrde";
@@ -174,7 +170,7 @@ $lang['Moderator_status'] = "Moderator status";
 $lang['Allowed_Access'] = "Tillt tilltrde";
 $lang['Disallowed_Access'] = "Neka tilltrde";
 $lang['Is_Moderator'] = "r Moderator";
-$lang['Not_Moderator'] = "r inte Moderator";
+$lang['Not_Moderator'] = "r inte moderator";
 
 $lang['Conflict_warning'] = "Varning! Auktorisationskonflikt";
 $lang['Conflict_access_userauth'] = "Denna anvndare har fortfarande tillgng till detta forum via gruppmedlemskap. Du kanske vill ndra grupprttigheterna eller ta bort denna anvndare frn gruppen fr att frhindra att de har tilltrde. Gruppens rttigheter (och berrda forum) listas nedan.";
@@ -378,7 +374,7 @@ $lang['Create_category'] = "Skapa ny kategori";
 $lang['Remove'] = "Radera";
 $lang['Action'] = "Handling";
 $lang['Update_order'] = "Uppdatera sorteringsordning";
-$lang['Config_updated'] = "Forum konfigurationen r uppdaterad";
+$lang['Config_updated'] = "Forumkonfigurationen r uppdaterad";
 $lang['Edit'] = "ndra";
 $lang['Delete'] = "Radera";
 $lang['Move_up'] = "Flytta upp";
@@ -397,11 +393,11 @@ $lang['Forum_settings'] = "Generella foruminstllningar";
 $lang['Forum_name'] = "Forumnamm";
 $lang['Forum_desc'] = "Beskrivning";
 $lang['Forum_status'] = "Forum status";
-$lang['Forum_pruning'] = "Auto-rensning";
+$lang['Forum_pruning'] = "Autoreducering";
 
 $lang['prune_freq'] = 'Sk efter gamla mnen varje';
 $lang['prune_days'] = "Ta bort mnen som inte har svarats p efter";
-$lang['Set_prune_data'] = "Du har aktiverat auto-rensing fr detta forum men har inte satt en frekvens eller antal dagar fr reducering. G tillbaka och stt detta";
+$lang['Set_prune_data'] = "Du har aktiverat autoreducering fr detta forum men har inte satt en frekvens eller antal dagar fr reducering. G tillbaka och stt detta";
 
 $lang['Move_and_Delete'] = "Flytta och radera";
 
@@ -490,7 +486,7 @@ $lang['Added_new_group'] = "Den nya gruppen r skapad";
 $lang['Deleted_group'] = "Gruppen r raderad";
 $lang['New_group'] = "Skapa ny grupp";
 $lang['Edit_group'] = "Redigera grupp";
-$lang['group_name'] = "Grupp namn";
+$lang['group_name'] = "Gruppnamn";
 $lang['group_description'] = "Gruppbeskrivning";
 $lang['group_moderator'] = "Gruppmoderator";
 $lang['group_status'] = "Gruppstatus";
@@ -514,14 +510,14 @@ $lang['Look_up_group'] = "Sl upp en grupp";
 //
 // Prune Administration
 //
-$lang['Forum_Prune'] = "Forum rensning";
+$lang['Forum_Prune'] = "Forumreducering";
 $lang['Forum_Prune_explain'] = "Detta kommer att radera alla mnen dr inga nya inlgg har skrivits inom det antal dagar du angett. Om du inte anger ett nummer s kommer alla mnen att raderas. Det kommer inte att radera mnen inom vilka omrstningar fortfarande r aktiva och det kommer inte heller att ta bort tillknnagivelser. Du behver radera dessa mnen manuellt";
-$lang['Do_Prune'] = "Rensa";
+$lang['Do_Prune'] = "Reducera";
 $lang['All_Forums'] = "Alla forum";
 $lang['Prune_topics_not_posted'] = "Radera mnen med inga svar i efter detta antal dagar";
-$lang['Topics_pruned'] = "mnen rensade";
-$lang['Posts_pruned'] = "Inlgg rensade";
-$lang['Prune_success'] = "Rensningen gick bra";
+$lang['Topics_pruned'] = "mnen reducerade";
+$lang['Posts_pruned'] = "Inlgg reducerade";
+$lang['Prune_success'] = "Reduceringen gick bra";
 
 
 //
