@@ -1,6 +1,6 @@
 <?php
 /***************************************************************************
- *                          lang_faq.php [swedish]
+ *                          lang_faq.php [Swedish]
  *                            -------------------
  *   begin                : Wednesday Oct 3, 2001
  *   copyright            : (C) 2001 The phpBB Group
@@ -46,11 +46,12 @@
 //  *************************************
 //
 
-//
 // CONTRIBUTORS:
 //	 Add your details here if wanted, e.g. Name, username, email address, website
-// XXXX-XX-XX  Marcus Svensson, Janke Rnnblom, Bruce and Jakob Persson             - orginal translation to Swedish 
-// 2003-07-11  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)   - updated the translation to phpBB version 2.0.6 and fixed grammars
+// XXXX-XX-XX  Orginal translation to Swedish by Marcus Svensson, Janke Rnnblom, Bruce and Jakob Persson
+// 2003-07-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.5
+// 2003-08-12  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.6
+// 2005-01-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.11
 
 // 
 // To add an entry to your FAQ simply add a line to this file in this format:
@@ -76,7 +77,7 @@ $faq[] = array("Jag har registrerat mig tidigare men nu kan jag inte logga in ln
 
 
 $faq[] = array("--","Anvndarpreferenser och instllningar");
-$faq[] = array("Hur ndrar jag mina instllningar?", "Alla dina instllningar (om du har registrerat dig) r lagrade i databasen. Fr att ndra dom klicka p <u>Profil<u> lnken (visas oftast hgst upp p sidan). Detta lter dig ndra alla dina instllningar.");
+$faq[] = array("Hur ndrar jag mina instllningar?", "Alla dina instllningar (om du har registrerat dig) r lagrade i databasen. Fr att ndra dom klicka p Profillnken (visas oftast hgst upp p sidan). Detta lter dig ndra alla dina instllningar.");
 $faq[] = array("Tiden r inte rtt!", "Tiden r med all skerhet korrekt, dock vad du kanske ser r tid som visas i en annan tidszon r den du befinner dig i. Om s r fallet s br du ndra dina instllningar fr att tidszonen ska stmma verens med din plats, tex. Stockholm, Helsingfors, New York, Sydney, etc. Notera att fr att ndra tidszonen, och de flesta instllningarna, s mste du vara registrerad. S om du inte har registrerat dig s r det god tid att gra det nu, om du ursktar ordvitsen!");
 $faq[] = array("Jag har ndrat tidszonen och tiden r fortfarande fel!", "Om du r sker p att du har satt tidszonen korrekt och tiden fortfarande r felaktig s r \"Daylight Savings Time\" (eller sommartid som det kallas i Sverige och i andra lnder) det mest troliga svaret. Forumet r inte designat fr att hantera frndringarna mellan vinter och sommartid s under sommar mnaderna kan tiden vara en timme fel.");
 $faq[] = array("Mitt sprk finns inte i listan!", "Det mest troliga sklet fr detta r att antingen s har administratren inte installerat ditt sprk eller s har inte ngon versatt forumet till ditt sprk. Frga administratrerna om de inte kan installera det sprk du behver och om det inte finns s tag grna chansen och skapa en ny versttning. Mer information finns p phpBB websiten (se lnken lngst ner p sidorna)");
@@ -95,20 +96,20 @@ $faq[] = array("Varfr kan jag inte komma in i ett forum?", "Vissa forum kan vara
 $faq[] = array("Varfr kan jag inte rsta i omrstningar?", "Enbart registrerad anvndare kan rsta i omrstningar (fr att hindra fejkade resultat). Om du r registrerad och du fortfarande inte kan rsta s har du frmodligen inte rttigheter till att rsta.");
 
 
-$faq[] = array("--","Formatteringar och Rubrik/mnes typer");
+$faq[] = array("--","Formatteringar och rubrik/mnes typer");
 $faq[] = array("Vad r BBCode?", "BBCode r en speciell implementation av HTML, om du kan anvnda BBCode bestms av administratren (du kan ocks hindra anvndningen av BBCode i det aktuella meddelandet nr du skapar det). BBCode i sig r snarlikt HTML, taggar r omgrdade/inneslutna i hakparanteser [ och ] isf &lt; och &gt; och BBCode ger strre kontroll ver hur vad och hur ngonting visas. Fr mera information om BBCode titta i guiden som kan ns frn nytt meddelande sidan.");
 $faq[] = array("Kan jag anvnda HTML?", "Det beror p om administratren tillter dig, de har total kontroll ver det. Om det r tilltet kommer du att finna att det bara r vissa taggar som fungerar. Detta r en <i>skerhets</i> tgrd fr att hindra folk frn att missbruka forumet genom att anvnda taggar som kan frstra designen eller skapa andra problem. Om HTLM r tillt s kan du hindra det i det aktuella meddelandet nr du skapar det.");
-$faq[] = array("Vad r Smileys?", "Smileys, eller Emoticons r sm grafiska bilder som kan anvndas fr att uttrycka ngon typ av knsla via en frkortning, e.g. :) betyder lycklig, :( betyder ledsen. Hela listan av emoticons kan du hitta via nytt meddelande formulret. Frsk att inte veranvnda smileys, de kan fort f ett meddelande att bli olsbart och en moderator kan bestmma sig fr att redigera bort dem frn meddelandet eller radera hela meddelandet.");
-$faq[] = array("Kan jag posta bilder?", "Bilder kan visas i ditt meddelande. Dock finns det fr tillfllet ingen funktion fr att ladda upp bilder till forumet. Drfr mste du lnka till en bild som lagras p en publik webserver, e.g. http://www.some-unknown-place.net/my-picture.gif. Du kan inte lnka till bilder som lagras p din lokala PC (svida den inte r en publikt tillgnglig server) eller till bilder som lagras bakom auktoriserings mekanismer, e.g. hotmail eller yahoo mailkonto, lsenordsskyddade siter, etc. Fr att visa en bild s anvnd antingen BBCode [img] taggen eller motsvarande HTML (om det tillts).");
+$faq[] = array("Vad r smileys?", "Smileys, eller Emoticons r sm grafiska bilder som kan anvndas fr att uttrycka ngon typ av knsla via en frkortning, e.g. :) betyder lycklig, :( betyder ledsen. Hela listan av emoticons kan du hitta via nytt meddelande formulret. Frsk att inte veranvnda smileys, de kan fort f ett meddelande att bli olsbart och en moderator kan bestmma sig fr att redigera bort dem frn meddelandet eller radera hela meddelandet.");
+$faq[] = array("Kan jag posta bilder?", "Bilder kan visas i ditt meddelande. Dock finns det fr tillfllet ingen funktion fr att ladda upp bilder till forumet. Drfr mste du lnka till en bild som lagras p en publik webserver, t.ex. <pre>http://www.some-unknown-place.net/my-picture.gif</pre>. Du kan inte lnka till bilder som lagras p din lokala PC (svida den inte r en publikt tillgnglig server) eller till bilder som lagras bakom auktoriserings mekanismer, e.g. hotmail eller yahoo mailkonto, lsenordsskyddade siter, etc. Fr att visa en bild s anvnd antingen BBCode [img] taggen eller motsvarande HTML (om det tillts).");
 $faq[] = array("Vad r Viktiga mnen/meddelanden?", "Viktiga meddelande innehller oftast viktig information och du br lsa dom s fort som mjligt. Viktiga meddelande syns hgst upp p varje sida i det forum som de skrivs. Om du kan eller inte kan skriva viktiga meddelande beror p vilka rttigheter som behvs, vilka styrs av administratrerna.");
 $faq[] = array("Vad r Klistrade mnen/meddelanden?", "Klistrade mnen syns under viktiga meddelande och enbart p frsta sidan. De innehller ofta viktig information s du br lsa dom nr det r mjligt. Ssom med viktiga meddelande s r det administratrerna som bestmmer vilka rttigheter som behvs fr att kunna skriva Klistrade mnen.");
 $faq[] = array("Vad r lsta mnen/meddelanden?", "Lsta mnen skapas av antingen forum moderatorerna eller av forum-administratrerna. Du kan inte besvara ett lst mne och om den innehller en omrstning s stoppas denna automatiskt. mnen kan lsas av mnga skl.");
 
 
 $faq[] = array("--","Anvndarniver och grupper");
-$faq[] = array("Vad r Administratrer?", "Administratrer r personer som har den absolut hgst nivn av kontroll ver hela forumet. Dessa personer kan kontrollera alla aspekter av forumets drift vilket inkluderar att stta rttigheter, bannlysa anvndare, skapa anvndargrupper eller moderatorer, etc. De har ocks fulla moderator rttigheter i alla forum.");
-$faq[] = array("Vad r Moderatorer?", "Moderatorer r individer (eller grupper av individer) vilkas jobb det r att skta om de dagliga aktiviterna i forumet. De har rttigheter att redigera eller radera meddelanden och lsa, lsa upp, flytta, radera och dela rubriker i forumet som de modererar. Generellt s r moderaratorer dr fr att hindra personer frn att <i>komma ifrn mnet<i> eller att skriva missbrukande eller ansttligt material.");
-$faq[] = array("Vad r Anvndargrupper?", "Anvndargrupper r ett stt som forum-administratrerna anvnder fr att gruppera anvndare. Varje anvndare kan tillhra flera grupper (detta skiljer frn de flesta andra forumen) och varje grupp kan tilldelas individuella rttigheter. Detta gr det enkelt fr administratrer att ange flera anvndare som moderatorer fr ett forum eller ge dom tkomst till ett privat forum, etc.");
+$faq[] = array("Vad r administratrer?", "Administratrer r personer som har den absolut hgst nivn av kontroll ver hela forumet. Dessa personer kan kontrollera alla aspekter av forumets drift vilket inkluderar att stta rttigheter, bannlysa anvndare, skapa anvndargrupper eller moderatorer, etc. De har ocks fulla moderator rttigheter i alla forum.");
+$faq[] = array("Vad r moderatorer?", "Moderatorer r individer (eller grupper av individer) vilkas jobb det r att skta om de dagliga aktiviterna i forumet. De har rttigheter att redigera eller radera meddelanden och lsa, lsa upp, flytta, radera och dela rubriker i forumet som de modererar. Generellt s r moderaratorer dr fr att hindra personer frn att <i>komma ifrn mnet<i> eller att skriva missbrukande eller ansttligt material.</i>");
+$faq[] = array("Vad r anvndargrupper?", "Anvndargrupper r ett stt som forum-administratrerna anvnder fr att gruppera anvndare. Varje anvndare kan tillhra flera grupper (detta skiljer frn de flesta andra forumen) och varje grupp kan tilldelas individuella rttigheter. Detta gr det enkelt fr administratrer att ange flera anvndare som moderatorer fr ett forum eller ge dom tkomst till ett privat forum, etc.");
 $faq[] = array("Hur gr jag med i en anvndargrupp?", "Fr att ansluta dig till en anvndargrupp s klicka p anvndargrupplnken i sidhuvudet (beroende p designmallen som anvnds), du kan d visa alla anvndargrupper. Inte alla grupper r <i>ppna</i>, vissa r stngda och vissa kan ven vara dolda. Om gruppen r ppen kan du anska om att f bli medlem genom att klicka p lmplig knapp. Anvndargruppens moderator mste d i sin tur bevilja din anskan och kan ven frga varfr du vill bli medlem. Och tjata inte p moderatorerna om de nekar dig de har skerligen sina skl.");
 $faq[] = array("Hur blir jag moderator fr en anvndargrupp?", "Anvndargrupper skapas initialt av administratrerna och de utser ocks gruppmoderator. Om du r intresserad av att skapa en anvndargrupp s r din frsta kontakt ngon av administratrerna. Skicka ett personligt meddelande till de.");
 
